"use strict";
/**
 * Copyright 2023 actions-toolkit authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Git = void 0;
const exec_1 = require("./exec");
const context_1 = require("@actions/github/lib/context");
class Git {
    static context() {
        return __awaiter(this, void 0, void 0, function* () {
            const ctx = new context_1.Context();
            ctx.ref = yield Git.ref();
            ctx.sha = yield Git.fullCommit();
            return ctx;
        });
    }
    static isInsideWorkTree() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['rev-parse', '--is-inside-work-tree'])
                .then(out => {
                return out === 'true';
            })
                .catch(() => {
                return false;
            });
        });
    }
    static remoteSha(repo, ref) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['ls-remote', repo, ref]).then(out => {
                const [rsha] = out.split(/[\s\t]/);
                if (rsha.length == 0) {
                    throw new Error(`Cannot find remote ref for ${repo}#${ref}`);
                }
                return rsha;
            });
        });
    }
    static remoteURL() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['remote', 'get-url', 'origin']).then(rurl => {
                if (rurl.length == 0) {
                    return Git.exec(['remote', 'get-url', 'upstream']).then(rurl => {
                        if (rurl.length == 0) {
                            throw new Error(`Cannot find remote URL for origin or upstream`);
                        }
                        return rurl;
                    });
                }
                return rurl;
            });
        });
    }
    static ref() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['symbolic-ref', 'HEAD']);
        });
    }
    static fullCommit() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['show', '--format=%H', 'HEAD', '--quiet', '--']);
        });
    }
    static shortCommit() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['show', '--format=%h', 'HEAD', '--quiet', '--']);
        });
    }
    static tag() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Git.exec(['tag', '--points-at', 'HEAD', '--sort', '-version:creatordate']).then(tags => {
                if (tags.length == 0) {
                    return Git.exec(['describe', '--tags', '--abbrev=0']);
                }
                return tags.split('\n')[0];
            });
        });
    }
    static exec(args = []) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield exec_1.Exec.getExecOutput(`git`, args, {
                ignoreReturnCode: true,
                silent: true
            }).then(res => {
                if (res.stderr.length > 0 && res.exitCode != 0) {
                    throw new Error(res.stderr);
                }
                return res.stdout.trim();
            });
        });
    }
}
exports.Git = Git;
//# sourceMappingURL=git.js.map